@@ -22,14 +22,15 @@
 ## ---------------------------------------------------------------------
 import warnings
 import numpy as np
+import pandas as pd
 
+from . import adc_pp
 from .misc import cached_property
 from .timings import Timer, timed_member_call
 from .AdcMethod import AdcMethod
 from .FormatIndex import (FormatIndexAdcc, FormatIndexBase,
                           FormatIndexHfProvider, FormatIndexHomoLumo)
 from .visualisation import ExcitationSpectrum
-from .state_densities import compute_gs2state_optdm, compute_state_diffdm
 from .OneParticleOperator import product_trace
 from .FormatDominantElements import FormatDominantElements
 
@@ -285,8 +286,8 @@ class ExcitedStates:
     @timed_member_call(timer="_property_timer")
     def transition_dm(self):
         """List of transition density matrices of all computed states"""
-        return [compute_gs2state_optdm(self.property_method, self.ground_state,
-                                       evec, self.matrix.intermediates)
+        return [adc_pp.transition_dm(self.property_method, self.ground_state,
+                                     evec, self.matrix.intermediates)
                 for evec in self.excitation_vector]
 
     @cached_property
@@ -369,8 +370,8 @@ class ExcitedStates:
     @timed_member_call(timer="_property_timer")
     def state_diffdm(self):
         """List of difference density matrices of all computed states"""
-        return [compute_state_diffdm(self.property_method, self.ground_state,
-                                     evec, self.matrix.intermediates)
+        return [adc_pp.state_diffdm(self.property_method, self.ground_state,
+                                    evec, self.matrix.intermediates)
                 for evec in self.excitation_vector]
 
     @property
@@ -397,6 +398,16 @@ class ExcitedStates:
             for ddm in self.state_diffdm
         ])
 
+    @property
+    @mark_excitation_property()
+    def cross_section(self):
+        """List of one-photon absorption cross sections of all computed states"""
+        # TODO Source?
+        fine_structure = constants.fine_structure
+        fine_structure_au = 1 / fine_structure
+        prefac = 2.0 * np.pi ** 2 / fine_structure_au
+        return prefac * self.oscillator_strength
+
     def plot_spectrum(self, broadening="lorentzian", xaxis="eV",
                       yaxis="cross_section", width=0.01, **kwargs):
         """One-shot plotting function for the spectrum generated by all states
@@ -456,11 +467,7 @@ class ExcitedStates:
             absorption = np.linalg.norm(self.transition_dipole_moment, axis=1)
             ylabel = "Modulus of transition dipole (au)"
         elif yaxis in ["cross_section", "σ"]:
-            # TODO Source?
-            fine_structure = constants.fine_structure
-            fine_structure_au = 1 / fine_structure
-            prefac = 2.0 * np.pi**2 / fine_structure_au
-            absorption = prefac * self.oscillator_strength
+            absorption = self.cross_section
             ylabel = "Cross section (au)"
         elif yaxis in ["rot", "rotational_strength", "rotatory_strength"]:
             absorption = self.rotatory_strength
@@ -657,6 +664,61 @@ class ExcitedStates:
                 ret += separator
         return ret[:-1]
 
+    def to_dataframe(self):
+        """
+        Exports the ExcitedStates object as :class:`pandas.DataFrame`.
+        Atomic units are used for all values.
+        """
+        propkeys = self.excitation_property_keys
+        propkeys.extend(self.excitation_energy_corrections.keys())
+        data = {
+            "excitation": np.arange(0, self.size, dtype=int),
+            "kind": np.tile(self.kind, self.size)
+        }
+        for key in propkeys:
+            try:
+                d = getattr(self, key)
+            except NotImplementedError:
+                # some properties are not available for every backend
+                continue
+            if not isinstance(d, np.ndarray):
+                continue
+            if not np.issubdtype(d.dtype, np.number):
+                continue
+            if d.ndim == 1:
+                data[key] = d
+            elif d.ndim == 2 and d.shape[1] == 3:
+                for i, p in enumerate(["x", "y", "z"]):
+                    data[f"{key}_{p}"] = d[:, i]
+            elif d.ndim > 2:
+                warnings.warn(f"Exporting NumPy array for property {key}"
+                              f" with shape {d.shape} not supported.")
+                continue
+        df = pd.DataFrame(data=data)
+        df.set_index("excitation")
+        return df
+
+    @property
+    def excitation_property_keys(self):
+        """
+        Extracts the property keys which are marked
+        as excitation property with :func:`mark_excitation_property`.
+        """
+        ret = []
+        for key in dir(self):
+            if key == "excitations":
+                continue
+            if "__" in key or key.startswith("_"):
+                continue  # skip "private" fields
+            if not hasattr(type(self), key):
+                continue
+            if not isinstance(getattr(type(self), key), property):
+                continue
+            fget = getattr(type(self), key).fget
+            if hasattr(fget, "__excitation_property"):
+                ret.append(key)
+        return ret
+
     @property
     def excitations(self):
         """
